@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2016-08-04'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -77,10 +77,12 @@ sub munge_files {
     $self->_load_schema_modules;
     $self->_load_schemas_modules;
 
+  SAH_SCHEMAS_MODULE:
     for my $pkg (sort keys %{ $self->{_our_schemas_modules} }) {
         # ...
     }
 
+  SAH_SCHEMA_MODULE:
     for my $pkg (sort keys %{ $self->{_our_schema_modules} }) {
         my $file = $self->{_our_schema_modules}{$pkg};
 
@@ -127,12 +129,19 @@ sub munge_files {
 
             for my $subsch ($nsch, @$subschemas) {
                 my $nsubsch = Data::Sah::Normalize::normalize_schema($subsch);
-                my $res = Data::Sah::Resolve::resolve_schema(
-                    {
-                        schema_is_normalized => 1,
-                        return_intermediates => 1,
-                    },
-                    $nsubsch);
+                my $res;
+                eval {
+                    $res = Data::Sah::Resolve::resolve_schema(
+                        {
+                            schema_is_normalized => 1,
+                            return_intermediates => 1,
+                        },
+                        $nsubsch);
+                };
+                if ($@) {
+                    $self->log(["Can't resolve schema (%s), skipped collecting base schemas for %s", $@, $pkg]);
+                    last COLLECT_BASE_SCHEMAS;
+                }
                 my $intermediates = $res->[2];
                 for my $i (0..$#{$intermediates}-1) {
                     my $mod = "Sah::Schema::$intermediates->[$i]";
@@ -160,15 +169,24 @@ sub munge_files {
         }
 
         # create lib/Sah/SchemaR/*.pm
+      CREATE_SCHEMAR:
         {
             require Data::Dump;
             require Data::Sah::Resolve;
             require Dist::Zilla::File::InMemory;
 
-            my $rschema = Data::Sah::Resolve::resolve_schema(
-                {return_intermediates => 1},
-                $sch,
-            );
+            my $rschema;
+            eval {
+                $rschema = Data::Sah::Resolve::resolve_schema(
+                    {return_intermediates => 1},
+                    $sch,
+                );
+            };
+            if ($@) {
+                $self->log(["Can't resolve schema (%s), skipped creating SchemaR version for %s", $@, $pkg]);
+                last CREATE_SCHEMAR;
+            }
+
             my $rname = $file->name; $rname =~ s!^lib/Sah/Schema/!lib/Sah/SchemaR/!;
             my $rpkg  = $pkg; $rpkg =~ s/^Sah::Schema::/Sah::SchemaR::/;
             my $rfile = Dist::Zilla::File::InMemory->new(
@@ -191,6 +209,7 @@ sub munge_files {
 
                     "=head1 DESCRIPTION\n\n",
                     "This module is automatically generated by ".__PACKAGE__." during distribution build.\n\n",
+                    "A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema wihout having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.\n\n",
                 ),
             );
             $self->log(["Creating file %s", $rname]);
@@ -232,7 +251,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.003 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2016-07-22.
+This document describes version 0.004 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2016-08-04.
 
 =head1 SYNOPSIS
 
